<?php declare(strict_types=1);

namespace BitBadger\PDODocument\Mapper;

use BitBadger\PDODocument\Configuration;
use BitBadger\PDODocument\DocumentException;
use BitBadger\PDODocument\Mode;

/**
 * Map an EXISTS result to a boolean value
 */
class ExistsMapper implements Mapper
{
    /**
     * @inheritDoc
     * @throws DocumentException If the database mode has not been set
     */
    public function map(array $result): bool
    {
        return match (Configuration::$mode) {
            Mode::PgSQL  => (bool)$result[0],
            Mode::SQLite => (int)$result[0] > 0,
            default      => throw new DocumentException('Database mode not set; cannot map existence result'),
        };
    }
}
